@@ -133,7 +133,8 @@ class PressureTimeseries(MetTimeseries):
 
     """
 
-    def __init__(self, time, pressure_data):
+    def __init__(self, time, pressure_data,
+            popts=None, uncs=None):
         """
         Args:
             time (float, array): time of meteorological time-series
@@ -142,8 +143,7 @@ class PressureTimeseries(MetTimeseries):
             t0, Delta P, and FWHM values and uncertainties for a set of vortices
             detected in the pressure time-series collected contemporaneously
         """
-        super().__init__(time, pressure_data,
-                popts=None, uncs=None)
+        super().__init__(time, pressure_data)
 
         # matched filter parameters
         self.matched_filter_fwhm = None
